<?php

class WECR_Show_Content{

	function __construct() {
		add_action( 'woocommerce_before_my_account', array( $this, 'show_content' ) );
	}

	public function show_content(){

		$orders = $this->get_orders();

		$products = $this->get_products_for_order( $orders );

		if ( empty( $products ) ){
			return;
		}

		$content = $this->get_restricted_content( $products );
		if ( $content == null ){ return; }

		echo '<h2>';
		_e( 'Your Premium Content', 'wecr' );
		echo '</h2>';

		echo '<ul>';
		foreach( $content as $c ){
			echo '<li><a href="'. get_the_permalink( $c->ID) .'">'.get_the_title( $c->ID ).'</a></li>';
		}
		echo '</ul>';
	}

	private function get_restricted_content( $product_ids ){

		$posts = $this->get_all_restricted_content();
		$matches = $this->return_only_matched_posts( $posts, $product_ids );

		if ( ! empty( $matches ) && is_array( $matches ) ) {
			$match_args = array(
				'post_type'      => 'any',
				'posts_per_page' => - 1,
				'post__in'       => $matches,
			);

			$y = get_posts( $match_args );
		} else {
			$y = null;
		}

		return $y;

	}

	/**
	 * Returns only post_ids that have matches with product_ids
	 * @param $posts
	 * @param $product_ids
	 * @return array $matches
	 */
	private function return_only_matched_posts( $posts, $product_ids ){

		$matches = array();

		foreach( $posts as $p ){
			$meta = get_post_meta( absint( $p->ID ), '_wecr_easy_restrict_content' );

			if ( is_array( $meta[0] ) && array_intersect( $meta[0], $product_ids ) ){
				$matches[] = absint( $p->ID );
			}
		}

		return $matches;

	}

	private function get_all_restricted_content(){

		$args = array(
			'post_type' => 'any',
			'posts_per_page' => -1,
			'meta_query' => array(
				array(
					'key' => '_wecr_easy_restrict_content',
					'compare' => 'EXISTS',
				)
			)
		);

		$posts = get_posts( $args );

		return $posts;
	}

	private function get_products_for_order( $orders ){

		$order_ids = wp_list_pluck( $orders, 'ID' );
		$product_ids = array();

		foreach( $order_ids as $id ){
			$order_obj = new WC_Order( $id );
			$items = $order_obj->get_items();

			foreach( $items as $i ){
				$product_ids[] = absint( $i['product_id'] );
			}
		}

		return $product_ids;
	}

	private function get_orders(){

		$user_id = get_current_user_id();

		$args = array(
			'posts_per_page' => -1,
			'meta_key' => '_customer_user',
			'meta_value' => $user_id,
			'post_type' => 'shop_order',
			'post_status' => array( 'wc-completed' ),
		);

		$orders = get_posts( $args );

		return $orders;

	} // get_orders

}
$GLOBALS['wecr_show_content'] = new WECR_Show_Content();

